@@ -118,8 +118,6 @@ def format_test(msg, last_test_id, keyword):
     _indent = indent * (msg["test_id"].count('/') - 1)
     out = f"{_indent}{icon}{_keyword} {_name}\n"
 
-    if last_test_id:
-        last_test_id.pop()
     last_test_id.append(msg["test_id"])
 
     return out
@@ -140,8 +138,9 @@ def format_result(msg, last_test_id):
     _indent = indent * (msg["test_id"].count('/') - 1)
     out = f"{_indent}{_result}"
 
-    if last_test_id[-1] == msg["test_id"]:
+    if last_test_id and last_test_id[-1] == msg["test_id"]:
         out = cursor_up() + "\r" + out
+    last_test_id = []
 
     if result in ("Fail", "Error", "Null"):
         out += f" {_test}"
